:title: An Introduction to \TeX{}Lite
:author: Lucien Rae Gentil
:fontsize: 11pt

# Introduction

This is a basic example of a \TeX{}Lite document. You can use Markdown syntax to make words **bold** or *italic*, and even write `in-line code snippets`.

If you want advanced features, all standard in-line \LaTeX{} commands can be used seamlessly. For example, I'm writing this on \today{} and here are some words in \textsc{small caps}.

# Maths

One thing that \LaTeX{} documents are great for is maths typesetting. Using standard maths notation it's easy to write down that $E = mc^2$.

You can also write full-line equations:

$$$
    e^{\pi i} + 1 = 0
$$$

And multi-line aligned equations:

$$$
    x &= 4 \times 5 + 1
    x &= 20 + 1
    x &= 21
$$$

# Conclusion

\TeX{}Lite is a great open-source tool for writing well-typesetted documents with minimal overhead. \TeX{}Lite documents can also be exported straight to `.TeX` for whatever manual tinkering or styling you might want.